.. currentmodule:: hydromt_wflow.wflow_sediment
.. _api_model_sediment:

Wflow Sediment model
====================

Initialize
----------

.. autosummary::
   :toctree: ../generated/

   WflowSedimentModel

Build components
----------------

.. autosummary::
   :toctree: ../generated/

   WflowSedimentModel.setup_config
   WflowSedimentModel.setup_basemaps
   WflowSedimentModel.setup_rivers
   WflowSedimentModel.setup_lakes
   WflowSedimentModel.setup_reservoirs
   WflowSedimentModel.setup_lulcmaps
   WflowSedimentModel.setup_laimaps
   WflowSedimentModel.setup_canopymaps
   WflowSedimentModel.setup_soilmaps
   WflowSedimentModel.setup_riverwidth
   WflowSedimentModel.setup_riverbedsed
   WflowSedimentModel.setup_gauges
   WflowSedimentModel.setup_constant_pars

Model specific attributes
-------------------------

.. autosummary::
   :toctree: ../generated/

   WflowSedimentModel.flwdir
   WflowSedimentModel.basins
   WflowSedimentModel.rivers

Model specific methods
----------------------

.. autosummary::
   :toctree: ../generated/

   WflowSedimentModel.set_flwdir
   WflowSedimentModel.clip_staticmaps
   WflowSedimentModel.clip_forcing